﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = False

    ## These control the width and height of the screen.

    config.screen_width = 1024
    config.screen_height = 768

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"Alchemical Ink"

    # These control the name and version of the game, that are reported
    # with tracebacks and other debugging logs.
    config.name = "Alchemical Ink"
    config.version = "0.1"
    
    # This is also the image that appears in the Dock and application switcher
    # in OS X, so consider making it at least 256x256 with a transparent background.
    config.window_icon = "icon.png"

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.

    theme.austen(
        # Color scheme: White Chocolate
                                    
        ## The color of an idle widget face.
        widget = "#33271C",

        ## The color of a focused widget face.
        widget_hover = "#ECE7C4",

        ## The color of the text in a widget.
        widget_text = "#ffffcc",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#ffffff",

        ## The color of a disabled widget face. 
        disabled = "#614D3A",

        ## The color of disabled widget text.
        disabled_text = "#80654D",

        ## The color of informational labels.
        label = "#F1EBE5",

        ## The color of a frame containing widgets.
        frame = "#926841",

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "bg_mm",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "bg_gm",

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = False,

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.            
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.
    
    ## ------- Novel Mode ------------------------
    style.nvl_window.background = Frame("textbox2.png", 0, 0)
    style.nvl_vbox.box_spacing = 10
    menu = nvl_menu 
    # config.empty_window = nvl_show_core
    config.window_hide_transition = dissolve
    config.window_show_transition = dissolve
    

    ## ------- Window -----------------------------
    style.window.background = Frame("textbox.png", 0, 0)
    
    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    style.window.left_margin = 0
    style.window.right_margin = 0
    style.window.top_margin = 0
    style.window.bottom_margin = 3

    ## Padding is space inside the window, where the background is
    ## drawn.

    style.window.left_padding = 10
    style.window.right_padding = 5
    style.window.top_padding = 10
    style.window.bottom_padding = 10

    ## This is the minimum height of the window, including the margins
    ## and padding.

    style.window.yminimum = 250

    ## Center the text in the Say Window sometimes: 
    
    # def center_say_window():
    # style.window.xpos = 0.5
    # style.window.ypos = 0.5
    # style.rebuild()
    
    # --------- during scene ------------  
    # "blah"
    # $ center_say_window()
    # "centered blah" 
    
    ## Center the text in the Say Window ALWAYS.
    
    # style.window.xpos = 0.5
    # style.window.ypos = 0.5

    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    # style.mm_menu_frame.xpos = 0.5
    # style.mm_menu_frame.xanchor = 0.5
    # style.mm_menu_frame.ypos = 0.75
    # style.mm_menu_frame.yanchor = 0.5


    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    style.default.font = "COCKTL.TTF"
    style.default.size = 24
    style.default.color = "#666633" 
    
    ## Adds a shadow one pixel to the right and one pixel down
    style.default.drop_shadow = [(1, 1)] 
    style.default.drop_shadow_color = "#000000"
    
    ## Adds a white outline 4 pixels thick, and then a black outline, 2 pixels thick
    # style.default.outlines = [(4, "#ff0000", 0, 0), (2, "#fff", 0, 0)] 
    
    # style.default.outlines = [(1, "#666633", 0, 0)]
    
    style.default.hover_outlines = [(1, "#999933", 0, 0)]
    style.default.selected_outlines = [(1, "#cccc99", 0, 0)]
    style.default.selected_hover_outlines = [(1, "#999933", 0, 0)]

    ## aligned the text completely to the right 
    # style.default.xalign = 1.0 
    
    ## The Formula... 
    ## style.STYLE_NAME.PROPERTY = VALUE
    
    style.say_window.font = "LITTLELO.TTF"
    style.say_vbox.font = "LITTLELO.TTF"
    style.say_label.font = "LITTLELO.TTF"
    style.say_label.size = 34    


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.
    style.button.activate_sound = "click.wav"
    style.imagemap.activate_sound = "click.wav"
    style.imagemap_button.activate_sound = "click.wav"
    
    ## Sounds that are used when entering and exiting the game menu.
    config.enter_sound = "click.wav"
    config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.
    config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    config.main_menu_music = "mu/Kaleidoscope.mp3" 
    
    renpy.music.register_channel("nature", "music", True)


    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "README.html"


    #########################################
    ## Transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = fade

    ## Used when exiting the game menu to the game.
    config.exit_transition = fade

    ## Used between screens of the game menu.
    config.intra_transition = fade

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = fade

    ## Used when returning to the main menu from the game.
    config.game_main_transition = fade

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = fade

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = fade

    ## Used when a game is loaded.
    config.after_load_transition = fade

    ## Used when the window is shown.
    config.window_show_transition = dissolve

    ## Used when the window is hidden.
    config.window_hide_transition = dissolve


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "Alchemical Ink"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?
    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.
    config.default_text_cps = 100
    
    import os
    os.environ['SDL_VIDEO_CENTERED'] = '1'
    
    config.imagemap_cache = False
    

    #########################################
    ## More customizations can go here.
    
    ###Modifies the Universal styles
    
    ####I did not edit the Save/Load menu, but notice what does changes if I set the
    ####parent style, and what doesn't change because the child style is defined elsewhere.
    
    #All frames
    style.frame.background = Frame("ui/frame.png",10,10)
    
    #All buttons
    style.button.background = Frame("ui/button_idle.png",10,10)
    style.button.hover_background = Frame("ui/button_hover.png",10,10)
    style.button.selected_background = Frame("ui/button_selected.png",10,10)
    style.button.selected_hover_background = Frame("ui/button_hover.png",10,10)
    style.button.yminimum = 40
    
    style.button_text.color = "#fff"
    style.button_text.size = 22


    ##This will change the save/load slots.
    style.large_button.background = Frame("ui/save_button_idle.png",10,10)
    style.large_button.hover_background = Frame("ui/save_button_hover.png",10,10)
    style.large_button.selected_background = Frame("ui/save_button_selected.png",10,10)
    style.large_button.selected_hover_background = Frame("ui/save_button_hover.png",10,10)
    style.large_button.yminimum = 65
    style.large_button.ypadding = 10
    
    #Change the screenshot for saves
    config.thumbnail_width = 68
    config.thumbnail_height = 51
    
    
